# QAT-RPC

This package provides RPC (Remote Procedure Call) tooling for use with the OQC 
[QAT](https://oqc-community.github.io/qat/main/index.html) (Quantum Assembly Toolchain) compiler and runtime.

## Installation

### PyPI

The QAT-RPC package has not yet been released to PyPI.

### Building from Source

We use [poetry](https://python-poetry.org/) for dependency management and run on
[Python 3.10+](https://www.python.org/downloads/).
Once both of these are installed run this in the root folder to install all the dependencies that you need: `poetry install`

> If you are contributing to the project we recommend that you also run
> `poetry run pre-commit install`
> to enable pre-commit checks.

### Contributing

To take the first steps towards contributing to QAT-RPC, visit our
[contribution](https://github.com/oqc-community/qat-rpc/blob/main/CONTRIBUTING.rst) documents, which provides details about our
process.

We also encourage new contributors to familiarise themselves with the
[code of conduct](https://github.com/oqc-community/qat-rpc/blob/main/CODE_OF_CONDUCT.rst) and to adhere to these
expectations.

### Assistance

For support, please reach out in the [discussions](https://github.com/oqc-community/qat-rpc/discussions) tab of this repository or file an [issue](https://github.com/oqc-community/qat-rpc/issues).

### Licence

This code in this repository is licensed under the BSD 3-Clause Licence.
Please see [LICENSE](https://github.com/oqc-community/qat-rpc/blob/main/LICENSE) for more information.

### Feedback

Please let us know your feedback and any suggestions by reaching out in [Discussions](https://github.com/oqc-community/qat-rpc/discussions>).
Additionally, to report any concerns or
[code of conduct](https://github.com/oqc-community/qat-rpc/blob/main/CODE_OF_CONDUCT.rst) violations please use this
[form](https://docs.google.com/forms/d/e/1FAIpQLSeyEX_txP3JDF3RQrI3R7ilPHV9JcZIyHPwLLlF6Pz7iGnocw/viewform?usp=sf_link).
